@@ -49,7 +49,7 @@ we finish printing information to the screen.
 void
 topini(void)
 {
-    info (0, 0, 0);
+    info ("", "", "");
 }
 /*
 Write a message to one of the top lines.
@@ -63,7 +63,7 @@ static void vtopmsg(int line, const char *fmt, va_list varglist)
     if (line < 1 || line > NUMTOPS)
 	line = 1;
     (void) move (line - 1, 0);
-    vsprintf(junkbuf, fmt, varglist);
+    vsnprintf(junkbuf, sizeof(junkbuf), fmt, varglist);
     (void) addstr (junkbuf);
     (void) clrtoeol();
 }
@@ -234,7 +234,7 @@ get_strq(char *buf, int sizep)
     (void) refresh ();
     (void) getnstr (buf, sizep);
     need_delay = false;
-    info (0, 0, 0);
+    info ("", "", "");
     (void) crmode ();
 }
 
